@@ -17,15 +17,20 @@ makefolds <- function(ina, nfolds = 10, stratified = TRUE, seed = FALSE) {
     labs <- unique(ina)
     run <- list()
     for (i in 1:length(labs)) {
-      names <- which(ina == labs[i])
+      names <- which( ina == labs[i] )
       run[[i]] <- sample(names)
     }
     run <- unlist(run)
-    for (i in 1:length(ina)) {
+    for ( i in 1:length(ina) ) {
       k <- i %% nfolds
-      if (k == 0)  k <- nfolds
-      runs[[k]] <- c(runs[[k]], run[i])
+      if ( k == 0 )  k <- nfolds
+      runs[[k]] <- c( runs[[ k ]], run[i] )
     }
   }
+  for (i in 1:nfolds)  {
+    if ( any( is.na(runs[[ i ]]) ) )  runs[[ i ]] <- runs[[ i ]][ !is.na(runs[[ i ]]) ]
+  }
   runs
 }
+
+
